<?php
/**
 * @file solr.drush.inc
 *
 * Provides the "solr" service type to AEgir.
 *
 * This file only cares about the SOLR side of things.  Regardless of implementation,
 * Solr needs its SOLR_HOME, conf and data directories, so this file handles that part.
 *
 */

/**
 * Implements hook_drush_init()
 */
function solr_drush_init(){
  solr_provision_register_autoload();
}

/**
 * Register our directory as a place to find Provision classes.
 *
 * This allows Provision to autoload our classes, so that we don't need to
 * specifically include the files before we use the class.
 */
function solr_provision_register_autoload() {
  static $loaded = FALSE;
  if (!$loaded) {
    $loaded = TRUE;
    provision_autoload_register_prefix('Provision_', dirname(__FILE__));
  }
}

/**
 * Implements hook_provision_services()
 *
 *  Declares a new service type and a basic implementation of it.
 *  It matches the same service definition in the hosting front end.
 */
function solr_provision_services() {
  solr_provision_register_autoload();
  return array('solr' => NULL);
}

/**
 * Implements hook_provision_apache_vhost_config()
 * Adds the $_ENV['solr_url'] variable to the VHOST
 */
function solr_provision_apache_vhost_config($uri, $data) {
  drush_log('Adding server variable for solr_url to vhost config.');

  $host = $data['server']->remote_host;
  $port = $data['server']->solr_port;
  $path = "/" . $uri;

  return array(
    "SetEnv solr_host $host",
    "SetEnv solr_port $port",
    "SetEnv solr_path $path",
  );
}

/**
 * Append PHP code to Drupal's settings.php file.
 *
 * @param $uri
 *   URI for the site.
 * @param $data
 *   Associative array of data from provisionConfig_drupal_settings::data.
 *
 * @return
 *   Lines to add to the site's settings.php file.
 *
 *   @TODO: THIS IS FORCED UPON USERS at the moment.... we should detect if
 *   the site is using apachesolr or searchapi!
 *
 * @see provisionConfig_drupal_settings
 */
function solr_provision_drupal_config($uri, $data, $config = array()) {

  // @TODO: Support apachesolr.module as well.

//  $output =<<<php
//
///**
// * Implements hook_default_search_api_server().
// */
//function system_default_search_api_server() {
//  \$items = array();
//  \$items['devshop_solr'] = entity_import('search_api_server', '{
//    "name" : "DevShop Solr",
//    "machine_name" : "devshop_solr",
//    "description" : "Provided by DevShop.",
//    "class" : "search_api_solr_service",
//    "options" : {
//      "clean_ids" : true,
//      "site_hash" : true,
//      "scheme" : "http",
//      "host" : ' . \$_SERVER['solr_host'] . ',
//      "port" : ' . \$_SERVER['solr_port'] . ',
//      "path" : ' . \$_SERVER['solr_path'] . ',
//      "http_user" : "",
//      "http_pass" : "",
//      "excerpt" : 0,
//      "retrieve_data" : 0,
//      "highlight_data" : 0,
//      "skip_schema_check" : 0,
//      "solr_version" : "",
//      "http_method" : "AUTO"
//    },
//    "enabled" : "1"
//  }');
//  return \$items;
//}
//php;

  return $output;
}

